==> csbase-login-ca-0.1.1-jpf.zip: META-INF/main/java/br/com/petrobras/security/server/service/soap/UpdateApplicationEnvironment.java <==

package br.com.petrobras.security.server.service.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for updateApplicationEnvironment complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="updateApplicationEnvironment">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="messageHeader" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}soapMessageHeader" minOccurs="0"/>
 *         &lt;element name="applicationEnvironment" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}ApplicationEnvironmentDTO" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "updateApplicationEnvironment", propOrder = {
    "messageHeader",
    "applicationEnvironment"
})
public class UpdateApplicationEnvironment {

    protected SoapMessageHeader messageHeader;
    protected ApplicationEnvironmentDTO applicationEnvironment;

    /**
     * Gets the value of the messageHeader property.
     * 
     * @return
     *     possible object is
     *     {@link SoapMessageHeader }
     *     
     */
    public SoapMessageHeader getMessageHeader() {
        return messageHeader;
    }

    /**
     * Sets the value of the messageHeader property.
     * 
     * @param value
     *     allowed object is
     *     {@link SoapMessageHeader }
     *     
     */
    public void setMessageHeader(SoapMessageHeader value) {
        this.messageHeader = value;
    }

    /**
     * Gets the value of the applicationEnvironment property.
     * 
     * @return
     *     possible object is
     *     {@link ApplicationEnvironmentDTO }
     *     
     */
    public ApplicationEnvironmentDTO getApplicationEnvironment() {
        return applicationEnvironment;
    }

    /**
     * Sets the value of the applicationEnvironment property.
     * 
     * @param value
     *     allowed object is
     *     {@link ApplicationEnvironmentDTO }
     *     
     */
    public void setApplicationEnvironment(ApplicationEnvironmentDTO value) {
        this.applicationEnvironment = value;
    }

}

==> csbase-login-ca-0.1.2-jpf.zip: META-INF/main/java/br/com/petrobras/security/server/service/soap/UpdateApplicationEnvironment.java <==

package br.com.petrobras.security.server.service.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for updateApplicationEnvironment complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="updateApplicationEnvironment">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="messageHeader" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}soapMessageHeader" minOccurs="0"/>
 *         &lt;element name="applicationEnvironment" type="{http://v41.soap.service.server.fwca.petrobras.com.br/}ApplicationEnvironmentKitDTO" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "updateApplicationEnvironment", propOrder = {
    "messageHeader",
    "applicationEnvironment"
})
public class UpdateApplicationEnvironment {

    protected SoapMessageHeader messageHeader;
    protected ApplicationEnvironmentKitDTO applicationEnvironment;

    /**
     * Gets the value of the messageHeader property.
     * 
     * @return
     *     possible object is
     *     {@link SoapMessageHeader }
     *     
     */
    public SoapMessageHeader getMessageHeader() {
        return messageHeader;
    }

    /**
     * Sets the value of the messageHeader property.
     * 
     * @param value
     *     allowed object is
     *     {@link SoapMessageHeader }
     *     
     */
    public void setMessageHeader(SoapMessageHeader value) {
        this.messageHeader = value;
    }

    /**
     * Gets the value of the applicationEnvironment property.
     * 
     * @return
     *     possible object is
     *     {@link ApplicationEnvironmentKitDTO }
     *     
     */
    public ApplicationEnvironmentKitDTO getApplicationEnvironment() {
        return applicationEnvironment;
    }

    /**
     * Sets the value of the applicationEnvironment property.
     * 
     * @param value
     *     allowed object is
     *     {@link ApplicationEnvironmentKitDTO }
     *     
     */
    public void setApplicationEnvironment(ApplicationEnvironmentKitDTO value) {
        this.applicationEnvironment = value;
    }

}
